# Generated by Django 2.1.7 on 2019-02-12 08:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('nuntius', '0006_subscriber_verbose_name'),
    ]

    operations = [
        migrations.AlterField(
            model_name='campaign',
            name='message_content_text',
            field=models.TextField(blank=True, verbose_name='Message content (text)'),
        ),
    ]



# Generated by Django 2.0.7 on 2018-07-18 08:28

from django.db import migrations, models
import django.db.models.deletion
import stdimage.models


class Migration(migrations.Migration):

    dependencies = [("nuntius", "0001_initial")]

    operations = [
        migrations.CreateModel(
            name="MosaicoImage",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("file", stdimage.models.StdImageField(upload_to="mosaico")),
                ("created", models.DateTimeField(auto_now_add=True)),
            ],
        ),
        migrations.AddField(
            model_name="campaign",
            name="message_mosaico_data",
            field=models.TextField(blank=True, verbose_name="Mosaico data"),
        ),
    ]



from django.urls import path

from nuntius.views import MosaicoImageProcessorView

urlpatterns = [
    path(
        "img/",
        MosaicoImageProcessorView.as_view(),
        name="nuntius_mosaico_image_processor",
    )
]



import html2text
from PIL import Image, ImageDraw

_h = html2text.HTML2Text()
_h.ignore_images = True


def generate_plain_text(html_message):
    return _h.handle(html_message)


def generate_placeholder(width, height):
    image = Image.new("RGB", (int(width), int(height)), "#707070")
    draw = ImageDraw.Draw(image)

    x = 0
    y = 0
    line_size = 40
    while y < height:
        draw.polygon(
            [
                (x, y),
                (x + line_size, y),
                (x + line_size * 2, y + line_size),
                (x + line_size * 2, y + line_size * 2),
            ],
            fill="#808080",
        )
        draw.polygon(
            [
                (x, y + line_size),
                (x + line_size, y + line_size * 2),
                (x, y + line_size * 2),
            ],
            fill="#808080",
        )
        x = x + line_size * 2
        if x > width:
            x = 0
            y = y + line_size * 2

    (textwidth, textheight) = draw.textsize(f"{width} x {height}")
    draw.text(
        ((int(width) - textwidth) / 2, (int(height) - textheight) / 2),
        f"{width} x {height}",
        (255, 255, 255),
    )

    return image
